==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/FinancialChartCustomIndicatorArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { FinancialChartCustomIndicatorArgsDescription } from "./FinancialChartCustomIndicatorArgsDescription";
/**
 * @hidden
 */
export let FinancialChartCustomIndicatorArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialChartCustomIndicatorArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialChartCustomIndicatorArgsDescriptionMetadata.a == null) {
                FinancialChartCustomIndicatorArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialChartCustomIndicatorArgsDescriptionMetadata.c(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
            }
            if (a.k(FinancialChartCustomIndicatorArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
            a.item("Index", "Number:int");
        }
        static d(a) {
            FinancialChartCustomIndicatorArgsDescriptionMetadata.b(a);
            a.ad("FinancialChartCustomIndicatorArgs", () => new FinancialChartCustomIndicatorArgsDescription());
            a.ac("FinancialChartCustomIndicatorArgs", FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
        }
    }
    FinancialChartCustomIndicatorArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialChartCustomIndicatorArgsDescriptionMetadata, 'FinancialChartCustomIndicatorArgsDescriptionMetadata');
    FinancialChartCustomIndicatorArgsDescriptionMetadata.a = null;
    return FinancialChartCustomIndicatorArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/FinancialChartCustomIndicatorArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { FinancialChartCustomIndicatorArgsDescription } from "./FinancialChartCustomIndicatorArgsDescription";
/**
 * @hidden
 */
export let FinancialChartCustomIndicatorArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialChartCustomIndicatorArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialChartCustomIndicatorArgsDescriptionMetadata.a == null) {
                FinancialChartCustomIndicatorArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialChartCustomIndicatorArgsDescriptionMetadata.c(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
            }
            if (a.k(FinancialChartCustomIndicatorArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
            a.item("Index", "Number:int");
        }
        static d(a) {
            FinancialChartCustomIndicatorArgsDescriptionMetadata.b(a);
            a.ae("FinancialChartCustomIndicatorArgs", () => new FinancialChartCustomIndicatorArgsDescription());
            a.ad("FinancialChartCustomIndicatorArgs", FinancialChartCustomIndicatorArgsDescriptionMetadata.a);
        }
    }
    FinancialChartCustomIndicatorArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialChartCustomIndicatorArgsDescriptionMetadata, 'FinancialChartCustomIndicatorArgsDescriptionMetadata');
    FinancialChartCustomIndicatorArgsDescriptionMetadata.a = null;
    return FinancialChartCustomIndicatorArgsDescriptionMetadata;
})();
